@@ -4,7 +4,6 @@ import re
 import time
 
 import pytest
-from pymysql import util
 from pymysql.err import ProgrammingError
 
 
@@ -29,7 +28,7 @@ async def test_datatypes(connection, cursor, datatype_table):
     # insert values
     v = (
         True, -3, 123456789012, 5.7, "hello'\" world",
-        u"Espa\xc3\xb1ol",
+        "Espa\xc3\xb1ol",
         "binary\x00data".encode(encoding),
         datetime.date(1988, 2, 2),
         datetime.datetime.now().replace(microsecond=0),
@@ -42,7 +41,7 @@ async def test_datatypes(connection, cursor, datatype_table):
     await cursor.execute(
         "select b,i,l,f,s,u,bb,d,dt,td,t,st from test_datatypes")
     r = await cursor.fetchone()
-    assert util.int2byte(1) == r[0]
+    assert bytes([1]) == r[0]
     # assert v[1:8] == r[1:8])
     assert v[1:9] == r[1:9]
     # mysql throws away microseconds so we need to check datetimes
@@ -107,6 +106,20 @@ async def test_string(cursor, table_cleanup):
     assert (test_value,) == r
 
 
+@pytest.mark.run_loop
+async def test_string_with_emoji(cursor, table_cleanup):
+    await cursor.execute("DROP TABLE IF EXISTS test_string_with_emoji;")
+    await cursor.execute("CREATE TABLE test_string_with_emoji (a text) "
+                         "DEFAULT CHARACTER SET=\"utf8mb4\"")
+    test_value = "I am a test string with emoji 😄"
+    table_cleanup('test_string_with_emoji')
+    await cursor.execute("INSERT INTO test_string_with_emoji (a) VALUES (%s)",
+                         test_value)
+    await cursor.execute("SELECT a FROM test_string_with_emoji")
+    r = await cursor.fetchone()
+    assert (test_value,) == r
+
+
 @pytest.mark.run_loop
 async def test_integer(cursor, table_cleanup):
     await cursor.execute("CREATE TABLE test_integer (a INTEGER)")
@@ -135,10 +148,10 @@ async def test_binary_data(cursor, table_cleanup):
 async def test_untyped_convertion_to_null_and_empty_string(cursor):
     await cursor.execute("select null,''")
     r = await cursor.fetchone()
-    assert (None, u'') == r
+    assert (None, '') == r
     await cursor.execute("select '',null")
     r = await cursor.fetchone()
-    assert (u'', None) == r
+    assert ('', None) == r
 
 
 @pytest.mark.run_loop
@@ -235,10 +248,15 @@ def mysql_server_is(server_version, version_tuple):
     return server_version_tuple >= version_tuple
 
 
+def get_mysql_vendor(server_info):
+    return "mariadb" if "MariaDB" in server_info else "mysql"
+
+
 @pytest.mark.run_loop
 async def test_json(connection_creator, table_cleanup):
     connection = await connection_creator(
         charset="utf8mb4", autocommit=True)
+    # TODO do better
     server_info = connection.get_server_info()
     if not mysql_server_is(server_info, (5, 7, 0)):
         raise pytest.skip("JSON type is not supported on MySQL <= 5.6")
@@ -259,6 +277,9 @@ async def test_json(connection_creator, table_cleanup):
     r = await cursor.fetchone()
     assert json.loads(r[0]) == json.loads(json_str)
 
-    await cursor.execute("SELECT CAST(%s AS JSON) AS x", (json_str,))
-    r = await cursor.fetchone()
-    assert json.loads(r[0]) == json.loads(json_str)
+    # MariaDB does not support JSON as a type
+    # See also https://github.com/PyMySQL/PyMySQL/pull/1165
+    if get_mysql_vendor(connection.get_server_info()) == "mysql":
+        await cursor.execute("SELECT CAST(%s AS JSON) AS x", (json_str,))
+        r = await cursor.fetchone()
+        assert json.loads(r[0]) == json.loads(json_str)
